@@ -2,13 +2,9 @@
 use 5.008001; use strict; use warnings; use utf8;
 
 package Lingua::EN::Titlecase::Simple;
-$Lingua::EN::Titlecase::Simple::VERSION = '1.002';
+$Lingua::EN::Titlecase::Simple::VERSION = '1.003';
 # ABSTRACT: John Gruber's headline capitalization script
 
-sub __HERE__ () { sprintf "\n#line %d %s\n", (caller)[2,1] }
-
-eval __HERE__."use Exporter::Tidy all => [ 'titlecase' ]; 1" or die $@ if defined caller;
-
 our @SMALL_WORD
 	= qw/ (?<!q&)a an and as at(?!&t) but by en for if in of on or the to v[.]? via vs[.]? /;
 
@@ -59,9 +55,16 @@ sub titlecase {
 	wantarray ? @str : ( @str > 1 ) ? \@str : $str[0];
 }
 
+sub import {
+	my ( $class, $pkg, $file, $line ) = ( shift, caller );
+	die "Unknown symbol: $_ at $file line $line.\n" for grep 'titlecase' ne $_, @_;
+	no strict 'refs';
+	*{ $pkg . '::titlecase' } = \&titlecase if @_;
+}
+
 return 1 if defined caller;
 
-eval __HERE__.'use open qw( :encoding(UTF-8) :std ); 1' or die $@;
+eval 'use open qw( :encoding(UTF-8) :std ); 1' or die;
 my $opt_force = @ARGV && '-f' eq $ARGV[0];
 shift @ARGV if $opt_force;
 shift @ARGV if @ARGV && '--' eq $ARGV[0];
